@@ -4,7 +4,7 @@
 #  Tamas Jos (@skelsec)
 #
 
-from minikerberos.ccache import CCACHE
+from minikerberos.common.ccache import CCACHE
 
 def main():
 	import argparse
